# -*- coding: utf-8 -*-

# CC-Metrics -- Call Center Metrics from Asterisk PBX
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2014-2015 Enercoop, Easter-eggs
# https://gitlab.easter-eggs.com/ee/cc-metrics
#
# This file is part of CC-Metrics.
#
# CC-Metrics is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# CC-Metrics is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


""" PBX extensions helpers """

import importlib
import logging


log = logging.getLogger(__name__)

lookup = None


class ExtensionLookup(object):
    """ PBX dummy lookup class """

    def __init__(self):
        self.reset_cache()

    def reset_cache(self):
        pass

    def resolve(self, kind, value):
        return value

    def resolve_dst(self, dst):
        return self.resolve('dst', dst)

    def resolve_src(self, src):
        return self.resolve('src', src)

    def resolve_queue(self, queue):
        return self.resolve('queue', queue)


def initialize_lookup(settings):
    global lookup

    # Get class from settings
    class_ = settings.pop('lookup.class', None)
    if class_ is None:
        lookup = ExtensionLookup()
        return True

    module, class_ = class_.rsplit('.', 1)

    # Load class from module
    module = importlib.import_module(module)
    cls = getattr(module, class_)

    kwargs = dict(
        (key[7:], value)
        for key, value in settings.items()
        if key.startswith('lookup.')
    )

    lookup = cls(**kwargs)
