# -*- coding: utf-8 -*-

# CC-Metrics -- Call Center Metrics from Asterisk PBX
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2014 Enercoop, Easter-eggs
# https://gitlab.easter-eggs.com/ee/cc-metrics
#
# This file is part of CC-Metrics.
#
# CC-Metrics is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# CC-Metrics is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" PBX lookup using dosini file as datasource """


from ConfigParser import SafeConfigParser
import codecs
import logging
import os

from ccmetrics.extensions import ExtensionLookup
from rwlock import RWLock


log = logging.getLogger(__name__)


class INILookup(ExtensionLookup):

    def __init__(self, config_file=None):
        self.config_file = config_file
        self.rwlock = RWLock()

        # Calling inherited
        super(INILookup, self).__init__()

    def reset_cache(self):
        log.debug('Reloading extension lookup cache')

        self.rwlock.writer_acquire()

        self.cache = dict(extension={}, queue={})

        if not os.path.isfile(self.config_file):
            log.error('Invalid configuration file for INILookup: {0}'.format(self.config_file))
            return False

        if not os.access(self.config_file, os.R_OK):
            log.error('Not enough permissions to access configuration file {0}'.format(self.config_file))
            return False

        parser = SafeConfigParser()
        try:
            parser.readfp(codecs.open(self.config_file, 'r', 'utf8'))
        except:
            log.exception('Failed to read configuration file {0}'.format(self.config_file))
            return False

        for section in parser.sections():
            if section == 'queues':
                for k, v in parser.items(section):
                    self.cache['queue'][k] = v
                continue

            extensions = [extension.strip() for extension in parser.get(section, 'extensions', '').split()]
            for extension in extensions:
                self.cache['extension'][extension] = section

        self.rwlock.writer_release()

    def resolve(self, kind, extension):
        self.rwlock.reader_acquire()
        resolved = self.cache[kind].get(extension, extension)
        self.rwlock.reader_release()
        return resolved

    def resolve_dst(self, dst):
        return self.resolve('extension', dst)

    def resolve_src(self, src):
        return self.resolve('extension', src)
