# -*- coding: utf-8 -*-

# CC-Metrics -- Call Center Metrics from Asterisk PBX
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2014-2015 Enercoop, Easter-eggs
# https://gitlab.easter-eggs.com/ee/cc-metrics
#
# This file is part of CC-Metrics.
#
# CC-Metrics is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# CC-Metrics is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


""" CC Metrics frontend forms """

import formencode
from formencode import validators
import logging

from common import DatetimeValidator
from common import SinceUntilValidator


log = logging.getLogger(__name__)


class RangeForm(formencode.Schema):
    allow_extra_fields = True
    filter_extra_fields = True

    format = validators.OneOf(['csv', 'html'], if_empty='html', if_missing='html')

    since = DatetimeValidator(format='%Y-%m-%dT%H:%M:%S.000Z', if_missing=None, if_empty=None)
    until = DatetimeValidator(format='%Y-%m-%dT%H:%M:%S.000Z', if_missing=None, if_empty=None)
    chained_validators = [SinceUntilValidator(strict=False)]


# incoming
class IncomingForm(RangeForm):
    dst = validators.String(if_empty=None, if_missing=None)
    internal = validators.StringBool(if_missing=False, if_empty=False)


# outgoing
class OutgoingForm(RangeForm):
    internal = validators.StringBool(if_missing=False, if_empty=False)
    src = validators.String(if_empty=None, if_missing=None)


# queue
class QueueForm(RangeForm):
    queue = validators.String(if_empty=None, if_missing=None)
