# -*- coding: utf-8 -*-

# CC-Metrics -- Call Center Metrics from Asterisk PBX
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2014-2015 Enercoop, Easter-eggs
# https://gitlab.easter-eggs.com/ee/cc-metrics
#
# This file is part of CC-Metrics.
#
# CC-Metrics is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# CC-Metrics is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


""" CC Metrics forms """

import formencode
from formencode import validators
import logging

from common import DatetimeValidator
from common import SinceUntilValidator


log = logging.getLogger(__name__)


class RangeForm(formencode.Schema):
    allow_extra_fields = True
    filter_extra_fields = True

    since = DatetimeValidator(format='%Y-%m-%dT%H:%M:%S.000Z', not_empty=True)
    until = DatetimeValidator(format='%Y-%m-%dT%H:%M:%S.000Z', not_empty=True)

    chained_validators = [SinceUntilValidator()]


# api.incoming.answered
# api.incoming.answered-slice
# api.incoming.duration
# api.incoming.duration-slice
# api.incoming.missed
# api.incoming.missed-slice
# api.incoming.ratio
# api.incoming.ratio-slice
# api.incoming.ranges
class IncomingForm(RangeForm):
    internal = validators.StringBool(if_missing=False, if_empty=False)
    dst = validators.String(if_missing=None, if_empty=None)


# api.outgoing.answered
# api.outgoing.answered-slice
# api.outgoing.duration
# api.outgoing.duration-slice
# api.outgoing.missed
# api.outgoing.missed-slice
# api.outgoing.ratio
# api.outgoing.ratio-slice
# api.outgoing.ranges
class OutgoingForm(RangeForm):
    internal = validators.StringBool(if_missing=False, if_empty=False)
    src = validators.String(if_missing=None, if_empty=None)


# api.queue.answered
# api.queue.answered-slice
# api.queue.duration
# api.queue.duration-slice
# api.queue.holdtime
# api.queue.holdtime-slice
# api.queue.missed
# api.queue.missed-slice
# api.queue.ratio
# api.queue.ratio-slice
# api.queue.ranges
class QueueForm(RangeForm):
    queue = validators.String(if_missing=None, if_empty=None)
