# -*- coding: utf-8 -*-

# CC-Metrics -- Call Center Metrics from Asterisk PBX
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2014-2015 Enercoop, Easter-eggs
# https://gitlab.easter-eggs.com/ee/cc-metrics
#
# This file is part of CC-Metrics.
#
# CC-Metrics is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# CC-Metrics is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


""" Database model """

from sqlalchemy import engine_from_config
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.ext.declarative import DeferredReflection

from sqlalchemy.orm import scoped_session
from sqlalchemy.orm import sessionmaker

from zope.sqlalchemy import ZopeTransactionExtension

DBSession = scoped_session(sessionmaker(extension=ZopeTransactionExtension()))
Base = declarative_base(cls=DeferredReflection)


class CDR(Base):
    __tablename__ = 'cdr'


class QueueLog(Base):
    __tablename__ = 'queue_log'

    @property
    def callerid(self):
        if self.event == 'ENTERQUEUE':
            return self.data2

        queue_log = DBSession.query(QueueLog).filter(
            QueueLog.event == 'ENTERQUEUE',
            QueueLog.callid == self.callid,
        ).first()
        if queue_log:
            return queue_log.callerid

        return None


def initialize_model(settings):

    engine = engine_from_config(settings, 'sqlalchemy.')
    DBSession.configure(bind=engine)
    Base.metadata.bind = engine
    Base.prepare(engine)
