# -*- coding: utf-8 -*-

# CC-Metrics -- Call Center Metrics from Asterisk PBX
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2014-2015 Enercoop, Easter-eggs
# https://gitlab.easter-eggs.com/ee/cc-metrics
#
# This file is part of CC-Metrics.
#
# CC-Metrics is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# CC-Metrics is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from dateutil.relativedelta import relativedelta
import sqlalchemy as sa


AGGREGATES = {
    'avg': sa.func.avg,
    'max': sa.func.max,
    'min': sa.func.min,
    'sum': sa.func.sum,
}


def get_aggregate(request):
    name = request.matchdict['aggregate']
    func = AGGREGATES[name]
    return (name, func)


def get_step(since, until):
    delta = relativedelta(until, since)

    if delta.years >= 1 or delta.months > 1:
        # delta >= 1 year
        # step is 1 month
        step = relativedelta(months=1)

    elif delta.days >= 2 or delta.months == 1:
        # delta >= 2 days
        # step is 1 day
        step = relativedelta(days=1)

    else:
        # step is 1 hour
        step = relativedelta(hours=1)

    # Steps
    current = since
    steps = []
    while current < until:
        steps.append(current)
        current = current + step

    return (steps, step, len(steps))
